@@ -11,9 +11,18 @@
 ##' xe_query = XenaQuery(xe)
 ##' }
 XenaQuery <- function(x) {
+  use_hiplot <- getOption("use_hiplot", default = FALSE)
+
+  data_list <- UCSCXenaTools::XenaData
+  if (use_hiplot) {
+    message("Use hiplot server (China) for mirrored data hubs (set 'options(use_hiplot = FALSE)' to disable it)")
+    data_list$XenaHosts <- .xena_mirror_map_rv[data_list$XenaHosts]
+  }
+
   message("This will check url status, please be patient.")
   datasetsName <- datasets(x)
-  query <- UCSCXenaTools::XenaData %>%
+
+  query <- data_list %>%
     dplyr::filter(XenaDatasets %in% datasetsName) %>%
     dplyr::rename(hosts = XenaHosts, datasets = XenaDatasets) %>%
     dplyr::mutate(url = ifelse(.data$XenaHostNames == "gdcHub",
